Reference
=============
.. automodule:: spector

indices
^^^^^^^^^^^
.. autoclass:: indices
   :members:
   :special-members:

vector
^^^^^^^^^^^
.. autoclass:: vector
   :members:
   :special-members:

matrix
^^^^^^^^^^^
.. autoclass:: matrix
   :show-inheritance:
   :members:

   .. automethod:: __add__
   .. automethod:: __mul__
   .. automethod:: __matmul__

groupby
^^^^^^^^^^^
.. autofunction:: groupby
